@@ -4,7 +4,7 @@ Project: pyautd
 Created Date: 11/02/2020
 Author: Shun Suzuki
 -----
-Last Modified: 14/09/2021
+Last Modified: 02/10/2021
 Modified By: Shun Suzuki (suzuki@hapis.k.u-tokyo.ac.jp)
 -----
 Copyright (c) 2020 Hapis Lab. All rights reserved.
@@ -324,9 +324,9 @@ class Modulation:
         return mod
 
     @ staticmethod
-    def square(freq: int, low: int = 0, high: int = 255):
+    def square(freq: int, low: int = 0, high: int = 255, duty: float = 0.5):
         mod = Modulation()
-        NATIVE_METHODDS.autd3capi.AUTDModulationSquare(byref(mod.modulation_ptr), freq, low, high)
+        NATIVE_METHODDS.autd3capi.AUTDModulationSquare(byref(mod.modulation_ptr), freq, low, high, duty)
         return mod
 
 
@@ -428,7 +428,7 @@ class Link:
             sb_desc = ctypes.create_string_buffer(128)
             sb_name = ctypes.create_string_buffer(128)
             NATIVE_METHODDS.autd3capi_soem_link.AUTDGetAdapter(handle, i, sb_desc, sb_name)
-            res.append([sb_name.value.decode('utf-8'), sb_desc.value.decode('utf-8')])
+            res.append([sb_name.value.decode('mbcs'), sb_desc.value.decode('mbcs')])
 
         NATIVE_METHODDS.autd3capi_soem_link.AUTDFreeAdapterPointer(handle)
 
@@ -439,7 +439,7 @@ class Link:
         NATIVE_METHODDS.init_autd3capi_soem_link()
         link = Link()
         error_handler = ErrorHandlerFunc(error_handler) if error_handler is not None else None
-        NATIVE_METHODDS.autd3capi_soem_link.AUTDLinkSOEM(byref(link.link_ptr), ifname.encode('utf-8'), dev_num, cycle_ticks, error_handler)
+        NATIVE_METHODDS.autd3capi_soem_link.AUTDLinkSOEM(byref(link.link_ptr), ifname.encode('mbcs'), dev_num, cycle_ticks, error_handler)
         return link
 
     @ staticmethod
@@ -454,9 +454,9 @@ class Link:
         NATIVE_METHODDS.autd3capi_twincat_link.AUTDLinkRemoteTwinCAT(
             byref(
                 link.link_ptr),
-            remote_ip_addr.encode('utf-8'),
-            remote_ams_net_id.encode('utf-8'),
-            local_ams_net_id.encode('utf-8'))
+            remote_ip_addr.encode('mbcs'),
+            remote_ams_net_id.encode('mbcs'),
+            local_ams_net_id.encode('mbcs'))
         return link
 
     @ staticmethod
@@ -479,7 +479,7 @@ class AUTD:
         size = NATIVE_METHODDS.autd3capi.AUTDGetLastError(None)
         err = ctypes.create_string_buffer(size)
         NATIVE_METHODDS.autd3capi.AUTDGetLastError(err)
-        return err.value.decode('utf-8')
+        return err.value.decode('mbcs')
 
     def open(self, link: Link):
         return NATIVE_METHODDS.autd3capi.AUTDOpenController(self.p_cnt, link.link_ptr)
@@ -493,7 +493,7 @@ class AUTD:
             sb_cpu = ctypes.create_string_buffer(128)
             sb_fpga = ctypes.create_string_buffer(128)
             NATIVE_METHODDS.autd3capi.AUTDGetFirmwareInfo(handle, i, sb_cpu, sb_fpga)
-            res.append([sb_cpu.value.decode('utf-8'), sb_fpga.value.decode('utf-8')])
+            res.append([sb_cpu.value.decode('mbcs'), sb_fpga.value.decode('mbcs')])
 
         NATIVE_METHODDS.autd3capi.AUTDFreeFirmwareInfoListPointer(handle)
 
@@ -552,6 +552,22 @@ class AUTD:
     def force_fan(self, value: bool):
         return NATIVE_METHODDS.autd3capi.AUTDSetForceFan(self.p_cnt, value)
 
+    @ property
+    def output_balance(self):
+        return NATIVE_METHODDS.autd3capi.AUTDIsOutputBalance(self.p_cnt)
+
+    @ output_balance.setter
+    def output_balance(self, value: bool):
+        return NATIVE_METHODDS.autd3capi.AUTDSetOutputBalance(self.p_cnt, value)
+
+    @ property
+    def check_ack(self):
+        return NATIVE_METHODDS.autd3capi.AUTDIsCheckAck(self.p_cnt)
+
+    @ check_ack.setter
+    def check_ack(self, value: bool):
+        return NATIVE_METHODDS.autd3capi.AUTDSetCheckAck(self.p_cnt, value)
+
     @ property
     def wavelength(self):
         return NATIVE_METHODDS.autd3capi.AUTDGetWavelength(self.p_cnt)
